<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>QtGui::DevView</name>
    <message>
        <location filename="../gui/devview.cpp" line="59"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="65"/>
        <source>Copy name</source>
        <translation>Namen kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="68"/>
        <source>Copy ID</source>
        <translation>ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="74"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/devview.cpp" line="79"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
</context>
<context>
    <name>QtGui::DirView</name>
    <message>
        <location filename="../gui/dirview.cpp" line="75"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="81"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="84"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="89"/>
        <source>Rescan</source>
        <translation>Scannen</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="94"/>
        <source>Resume</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="99"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../gui/dirview.cpp" line="103"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
</context>
<context>
    <name>QtGui::DownloadView</name>
    <message>
        <location filename="../gui/downloadview.cpp" line="65"/>
        <source>Copy value</source>
        <translation>Wert kopieren</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="70"/>
        <source>Copy label/ID</source>
        <translation>Namen/ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/downloadview.cpp" line="74"/>
        <source>Open in file browser</source>
        <translation>Im Dateibrowser öffnen</translation>
    </message>
</context>
<context>
    <name>QtGui::TrayIcon</name>
    <message>
        <location filename="../gui/trayicon.cpp" line="58"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="62"/>
        <source>Rescan all</source>
        <translation>Alle neu scannen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="70"/>
        <source>Show internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="75"/>
        <source>About</source>
        <translation>Über Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="80"/>
        <source>Close</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="214"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="234"/>
        <source>Launcher error</source>
        <translation>Starter-Fehler</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="250"/>
        <source>Syncthing notification - click to dismiss</source>
        <translation>Neue Syncthing-Benachrichtigung</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="280"/>
        <source>Syncthing device wants to connect - click for web UI</source>
        <translation>Neues Gerät möchte verbinden</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="296"/>
        <source>New Syncthing directory - click for web UI</source>
        <translation>Neues Syncthing-Verzeichnis</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="175"/>
        <source>Disconnected from Syncthing</source>
        <translation>Verbindung zu Syncthing getrennt</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="54"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../gui/trayicon.cpp" line="66"/>
        <source>Log</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtGui::TrayWidget</name>
    <message>
        <location filename="../gui/traywidget.ui" line="6"/>
        <source>Syncthing Tray</source>
        <translation>Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="97"/>
        <location filename="../gui/traywidget.cpp" line="337"/>
        <source>About</source>
        <translation>Über Syncthing Tray</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="58"/>
        <location filename="../gui/traywidget.cpp" line="460"/>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="71"/>
        <location filename="../gui/traywidget.cpp" line="834"/>
        <location filename="../gui/traywidget.cpp" line="876"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="110"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="123"/>
        <source>Open Syncthing</source>
        <translation>Syncthing öffnen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="283"/>
        <source>In</source>
        <translation>eing.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="290"/>
        <source>Incoming traffic</source>
        <translation>Eingehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="222"/>
        <location filename="../gui/traywidget.ui" line="242"/>
        <location filename="../gui/traywidget.ui" line="293"/>
        <location filename="../gui/traywidget.ui" line="313"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="212"/>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="219"/>
        <source>Global overall statistics</source>
        <translation>Globale Gesamtstatistiken</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="229"/>
        <source>Local</source>
        <translation>Lokal</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="239"/>
        <source>Local overall statistics</source>
        <translation>Lokale Gesamtstatistiken</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="300"/>
        <source>Out</source>
        <translation>ausg.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="310"/>
        <source>Outgoing traffic</source>
        <translation>Ausgehender Datenverkehr</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="350"/>
        <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
        <translation>Klicke um &lt;i&gt;neue&lt;/i&gt; Benachrichtigungen zu zeigen&lt;br&gt;
(für &lt;i&gt;alle&lt;/i&gt; Benachrichtigungen, in den Log schauen)</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="354"/>
        <location filename="../gui/traywidget.cpp" line="157"/>
        <location filename="../gui/traywidget.cpp" line="380"/>
        <source>New notifications</source>
        <translation>Neue Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="384"/>
        <source>Directories</source>
        <translation>Verzeichnisse</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="416"/>
        <source>Devices</source>
        <translation>Geräte</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="448"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="476"/>
        <source>Recent changes</source>
        <translatorcomment>&quot;Letzte Änderungen&quot; is too long</translatorcomment>
        <translation>Änderungen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="512"/>
        <source>Show</source>
        <translation>Zeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.ui" line="522"/>
        <source>Dismiss</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="129"/>
        <source>View own device ID</source>
        <translation>Eigene Geräte-ID anzeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="134"/>
        <source>Restart Syncthing</source>
        <translation>Syncthing neustarten</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="139"/>
        <source>Show Syncthing log</source>
        <translation>Syncthing-Log zeigen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="144"/>
        <source>Rescan all directories</source>
        <translation>Alle Verzeichnisse neu scannen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="151"/>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="173"/>
        <source>Show internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="188"/>
        <source>Quit Syncthing Tray</source>
        <translation>Syncthing Tray schließen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="435"/>
        <source>Do you really want to restart Syncthing?</source>
        <translation>Soll Syncthing wirklich neu gestartet werden?</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="461"/>
        <source>Not connected to Syncthing, click to connect</source>
        <translation>Verbindung zu Syncthing getrennt, klicke um zu verbinden</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="466"/>
        <source>Unable to establish connection to Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="476"/>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="477"/>
        <source>Syncthing is running, click to pause all devices</source>
        <translation>Syncthing läuft, klicke um alle Geräte zu pausieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="482"/>
        <source>Continue</source>
        <translation>Fortsetzen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="483"/>
        <source>At least one device is paused, click to resume</source>
        <translation>Mind. ein Gerät ist pausiert, klicke um fortzusetzen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="603"/>
        <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
        <translation>Die angegebene Verbindungskonfiguration &lt;em&gt;%1&lt;/em&gt; ist nicht definiert und wird daher ignoriert.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="638"/>
        <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Das Verzeichnis &lt;i&gt;%1&lt;/i&gt; existiert nicht lokal.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="649"/>
        <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
        <translation>Das beinhaltende Verzeichnis &lt;i&gt;%1&lt;/i&gt; existiert nicht lokal.</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="692"/>
        <source>Copy path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="696"/>
        <source>Copy device ID</source>
        <translation>Geräte-ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="699"/>
        <source>Copy directory ID</source>
        <translation>Verzeichnis-ID kopieren</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="830"/>
        <location filename="../gui/traywidget.cpp" line="870"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="831"/>
        <source>Stop Syncthing instance launched via tray icon</source>
        <translation>Stoppe Syncthing-Instanz, die mit dem internen Starter gestartet wurde</translation>
    </message>
    <message>
        <location filename="../gui/traywidget.cpp" line="835"/>
        <source>Start Syncthing with the built-in launcher configured in the settings</source>
        <translation>Starte Syncthing mit dem eingebauten Starter, der in den Einstellungen konfiguriert wird</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../application/main.cpp" line="58"/>
        <source>Unable to </source>
        <translation>Fehler beim </translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="91"/>
        <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
        <translation>Das System-Tray bzw. der Infobereich ist aktuell nicht verfügbar. Mit der Option &quot;--windowed&quot; ist es möglich, Syncthing Tray als normales Fenster zu starten. Außerdem ist es möglich mit der Option &quot;--wait&quot; zu warten bis das System-Tray verfügbar ist anstelle diesen Dialog zu zeigen.</translation>
    </message>
    <message>
        <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
        <translation type="vanished">Vor der ersten Verwendung muss eingestellt werden, wie sich das Syncthing Tray mit Syncthing verbinden soll.</translation>
    </message>
    <message>
        <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="vanished">Der Einstellungsdialog ermöglicht es die URL, Zugangsdaten und den API-Key automatisch aus der lokalen Syncthing-Konfiguration auszulesen.</translation>
    </message>
    <message>
        <location filename="../application/main.cpp" line="118"/>
        <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
        <translation>Die verwendete Qt-Bibliothek wurde nicht mit Unterstützung für System-Tray konfiguriert. Es wäre möglich, Syncthing Tray als normales Fenster zu starten (mit Option -w).</translation>
    </message>
</context>
</TS>
